[PATCH] D114834: [clang]Fix assertion failure when passing bool as the type of next parameter

Lucas Wang via Phabricator via cfe-commits cfe-commits at lists.llvm.org
Tue Nov 30 17:28:13 PST 2021


Lucas created this revision.
Lucas requested review of this revision.
Herald added a project: clang.
Herald added a subscriber: cfe-commits.

Repository:
  rG LLVM Github Monorepo

https://reviews.llvm.org/D114834

Files:
  clang/lib/Sema/SemaExpr.cpp
  clang/test/SemaCXX/varargs.cpp


Index: clang/test/SemaCXX/varargs.cpp
===================================================================
--- clang/test/SemaCXX/varargs.cpp
+++ clang/test/SemaCXX/varargs.cpp
@@ -53,6 +53,8 @@
 
   // Ensure that signed vs unsigned doesn't matter either.
   (void)__builtin_va_arg(ap, unsigned int);
+
+  (void)__builtin_va_arg(ap, bool); // expected-warning {{second argument to 'va_arg' is of promotable type 'bool'; this va_arg has undefined behavior because arguments will be promoted to 'int'}}
 }
 
 #if __cplusplus >= 201103L
Index: clang/lib/Sema/SemaExpr.cpp
===================================================================
--- clang/lib/Sema/SemaExpr.cpp
+++ clang/lib/Sema/SemaExpr.cpp
@@ -15902,9 +15902,10 @@
 
       // If the types are still not compatible, we need to test whether the
       // promoted type and the underlying type are the same except for
       // signedness. Ask the AST for the correctly corresponding type and see
       // if that's compatible.
       if (!PromoteType.isNull() &&
+          !UnderlyingType->isBooleanType() &&
           PromoteType->isUnsignedIntegerType() !=
               UnderlyingType->isUnsignedIntegerType()) {
         UnderlyingType =


-------------- next part --------------
@@ -15902,9 +15902,10 @@
       // If the types are still not compatible, we need to test whether the
       // promoted type and the underlying type are the same except for
-      // signedness. Ask the AST for the correctly corresponding type and see
-      // if that's compatible.
+      // signedness except for boolean. Ask the AST for the correctly corresponding
+      // type and see if that's compatible.
       if (!PromoteType.isNull() &&
A non-text attachment was scrubbed...
Name: D114834.390871.patch
Type: text/x-patch
Size: 1336 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/cfe-commits/attachments/20211201/8628c5bb/attachment.bin>


More information about the cfe-commits mailing list